DecodeError

Enum DecodeError 

#[non_exhaustive]
pub enum DecodeError { EmptyDelimiter, InvalidParameterLimit, DecodeDotInKeysRequiresAllowDots, ParameterLimitExceeded { limit: usize, }, ListLimitExceeded { limit: usize, }, DepthExceeded { depth: usize, }, Serde(Error), }
Errors that can occur while decoding a query string into an crate::Object.

This enum is marked non_exhaustive so additional variants can be added in future releases without breaking downstream matches.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyDelimiter

The configured delimiter string was empty.



InvalidParameterLimit

The configured parameter limit was zero.



DecodeDotInKeysRequiresAllowDots



ParameterLimitExceeded

The decoded input exceeded the configured parameter limit.

Fields

limit: usize

The configured maximum number of parameters.



ListLimitExceeded

A decoded list exceeded the configured list limit.

Fields

limit: usize

The configured maximum list length.



DepthExceeded

The decoded nesting depth exceeded the configured limit.

Fields

depth: usize

The configured maximum decode depth.



Serde(Error)

Serde deserialization failed after the query string was decoded into an intermediate crate::Value tree.

Implementations

Source

impl DecodeError

pub fn is_parameter_limit_exceeded(&self) -> bool

Returns true when the error reports that the parameter limit was exceeded.

pub fn parameter_limit(&self) -> Option<usize>

Returns the configured parameter limit for Self::ParameterLimitExceeded.

pub fn is_list_limit_exceeded(&self) -> bool

Returns true when the error reports that a list limit was exceeded.

pub fn list_limit(&self) -> Option<usize>

Returns the configured list limit for Self::ListLimitExceeded.

pub fn is_depth_exceeded(&self) -> bool

Returns true when the error reports that the nesting depth limit was exceeded.

pub fn depth_limit(&self) -> Option<usize>

Returns the configured depth limit for Self::DepthExceeded.