#[non_exhaustive]pub enum TemporalValueError {
InvalidMonth(u8),
InvalidDay {
year: i32,
month: u8,
day: u8,
},
InvalidHour(u8),
InvalidMinute(u8),
InvalidSecond(u8),
InvalidNanosecond(u32),
InvalidOffsetSeconds(i32),
InvalidFormat,
MissingOffset,
UnexpectedOffset,
OutOfRange,
}Expand description
Validation and parsing errors for TemporalValue and DateTimeValue.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMonth(u8)
The provided month was outside 1..=12.
InvalidDay
The provided day was invalid for the given month and year.
InvalidHour(u8)
The provided hour was outside 0..=23.
InvalidMinute(u8)
The provided minute was outside 0..=59.
InvalidSecond(u8)
The provided second was outside 0..=59.
InvalidNanosecond(u32)
The provided nanosecond value was outside 0..1_000_000_000.
InvalidOffsetSeconds(i32)
The provided UTC offset was outside the supported range.
InvalidFormat
A string could not be parsed as a canonical datetime value.
MissingOffset
A conversion required an offset-aware datetime, but none was present.
UnexpectedOffset
A conversion required a naive datetime, but an offset was present.
OutOfRange
A temporal value could not be represented by the requested target type.